@@ -5,7 +5,10 @@ from fastapi import FastAPI
 from faststream.rabbit import RabbitBroker
 from contextlib import asynccontextmanager
 
+from cattle_grid.app import app_globals
+from cattle_grid.app.lifespan import run_broker, common_lifespan
 from cattle_grid.testing.accounts import create_test_accounts
+from cattle_grid.exchange.exception import exception_middleware
 
 from .activity_pub.server import router as ap_router
 from .auth import auth_router
@@ -16,7 +19,6 @@ from .account.rabbit import rabbit_router
 from .extensions.load import add_routes_to_api, lifespan_from_extensions
 from .dependencies.globals import global_container
 
-from .exchange.exception import exception_middleware
 from .app import init_extensions, add_routers_to_broker
 
 from .version import __version__
@@ -60,39 +62,23 @@ def create_app(
     if run_migration:
         os.system(f"python -malembic -c {alembic_config} upgrade head")
 
-    if global_container.config.testing.enable:  # type:ignore
-        logger.warning("Running in testing mode")
-
     extensions = init_extensions(global_container.config)
 
     @asynccontextmanager
     async def lifespan(app: FastAPI, broker: RabbitBroker | None = None):
         if broker is None:
             broker = global_container.broker
-
         broker.add_middleware(exception_middleware)
-
-        async with global_container.common_lifecycle(global_container.config):  # type:ignore
-            await upgrade_sql_alchemy(global_container.engine)
+        async with common_lifespan():  # type:ignore
+            await upgrade_sql_alchemy(app_globals.engine)
 
             async with lifespan_from_extensions(extensions):
                 if global_container.config.processor_in_app:
                     add_routers_to_broker(broker, extensions, global_container.config)
-                session = global_container.async_session_maker()  # type: ignore
-                await create_test_accounts(session)
-
-                if global_container.config.amqp_uri == "amqp://:memory:":
-                    logger.warning("Using in memory amqp")
-                    from faststream.rabbit import TestRabbitBroker
-
-                    async with TestRabbitBroker(broker) as br:
-                        global_container.broker = br
-                        yield
-                else:
-                    await broker.start()
+                await create_test_accounts()
 
+                async with run_broker(broker):
                     yield
-                    await broker.stop()
 
     app = FastAPI(
         lifespan=lifespan,
