@@ -6,7 +6,7 @@ from fastapi import APIRouter, HTTPException
 
 from cattle_grid.database.account import AuthenticationToken
 from cattle_grid.account.account import account_with_name_password
-from cattle_grid.dependencies.fastapi import CommittingSqlSession
+from cattle_grid.dependencies.fastapi import CommittingSession
 
 from .responses import TokenResponse, SignInData
 from .actor import actor_router
@@ -21,7 +21,7 @@ router.include_router(account_router)
 
 
 @router.post("/signin", operation_id="signin")
-async def signin(data: SignInData, session: CommittingSqlSession) -> TokenResponse:
+async def signin(data: SignInData, session: CommittingSession) -> TokenResponse:
     """Allows one to sign in to an account on cattle_grid.
     The response a token to be included using bearer authentication."""
     account = await account_with_name_password(session, data.name, data.password)
