@@ -1,7 +1,11 @@
 from fastapi import APIRouter, HTTPException
 from sqlalchemy.ext.asyncio import AsyncSession
 from cattle_grid.model import FetchMessage
-from cattle_grid.dependencies.fastapi import ActivityExchangePublisher, SqlSession
+from cattle_grid.dependencies.fastapi import (
+    ActivityExchangePublisher,
+    ActivityExchangeRequester,
+    SqlSession,
+)
 
 from .dependencies import CurrentAccount
 from .responses import (
@@ -30,7 +34,7 @@ async def actor_from_account(
 async def lookup(
     body: LookupRequest,
     account: CurrentAccount,
-    publisher: ActivityExchangePublisher,
+    requester: ActivityExchangeRequester,
     session: SqlSession,
 ) -> dict:
     """Looks up the resource given by `uri` as the actor with
@@ -43,7 +47,7 @@ async def lookup(
 
     msg = FetchMessage(actor=actor.actor, uri=body.uri)
 
-    result = await publisher(msg, routing_key="fetch", rpc=True)  # type: ignore
+    result = await requester(msg, routing_key="fetch")  # type: ignore
     if not isinstance(result, dict):
         return {"raw": {}}
     return result
