@@ -2,7 +2,7 @@ import asyncio
 import logging
 import aio_pika
 
-from cattle_grid.dependencies.fastapi import Broker
+from cattle_grid.dependencies.fastapi_internals import Broker
 from cattle_grid.model.account import EventType
 
 from cattle_grid.tools import enqueue_to_routing_key_and_connection
