@@ -1,7 +1,7 @@
 from faststream.rabbit import RabbitRouter, RabbitExchange, RabbitQueue
 from typing import Any, List, Tuple
 
-from cattle_grid.dependencies.globals import global_container
+from cattle_grid.app import app_globals
 
 from .remote import fetch_object, sending_message
 from .outgoing import create_outgoing_router
@@ -12,7 +12,7 @@ from .shared_inbox import handle_shared_inbox_message
 
 def create_processing_router(exchange: RabbitExchange | None = None) -> RabbitRouter:
     if exchange is None:
-        exchange = global_container.internal_exchange
+        exchange = app_globals.internal_exchange
 
     router = RabbitRouter()
     router.include_router(create_outgoing_router(exchange))
