@@ -8,9 +8,7 @@ from bovine import BovineActor
 from cattle_grid.dependencies import ClientSession, SqlSession
 from cattle_grid.dependencies.processing import actor_id, ProcessingError
 
-from cattle_grid.activity_pub.actor import (
-    bovine_actor_for_actor_id,
-)
+from cattle_grid.activity_pub.actor.internals import bovine_actor_for_actor_id
 
 logger = logging.getLogger(__name__)
 
