@@ -5,11 +5,11 @@ from sqlalchemy import select, delete
 
 from bovine.activitystreams.utils import id_for_object
 
-from cattle_grid.activity_pub.actor import remove_from_followers_following
+from cattle_grid.activity_pub.actor.internals import remove_from_followers_following
+from cattle_grid.app import app_globals
 from cattle_grid.database.activity_pub_actor import Following, Follower
 from cattle_grid.model import ActivityMessage
 from cattle_grid.model.processing import StoreActivityMessage
-from cattle_grid.dependencies.globals import global_container
 from cattle_grid.dependencies.processing import MessageActor, FactoriesForActor
 from cattle_grid.dependencies import CommittingSession, InternalExchangePublisher
 from .util import actor_deletes_themselves
@@ -154,7 +154,7 @@ def create_incoming_router(exchange=None):
     router = RabbitRouter()
 
     if exchange is None:
-        exchange = global_container.internal_exchange
+        exchange = app_globals.internal_exchange
 
     for routing_key, coroutine in [
         ("incoming.Follow", incoming_follow_request),
