@@ -9,6 +9,7 @@ from bovine.activitystreams.utils import (
     remove_public,
 )
 
+from cattle_grid.app import app_globals
 from cattle_grid.database.activity_pub_actor import Following, Follower, Blocking
 from cattle_grid.model import ActivityMessage
 from cattle_grid.model.processing import ToSendMessage
@@ -17,7 +18,6 @@ from cattle_grid.dependencies import (
     InternalExchangePublisher,
     SqlSession,
 )
-from cattle_grid.dependencies.globals import global_container
 from cattle_grid.dependencies.processing import MessageActor
 
 from .util import update_recipients_for_collections
@@ -155,7 +155,7 @@ def create_outgoing_router(exchange=None):
     router = RabbitRouter()
 
     if exchange is None:
-        exchange = global_container.internal_exchange
+        exchange = app_globals.internal_exchange
 
     for routing_key, coroutine in [
         ("outgoing.Follow", outgoing_follow_request),
@@ -168,7 +168,7 @@ def create_outgoing_router(exchange=None):
         router.subscriber(
             RabbitQueue(routing_key, routing_key=routing_key, durable=True),
             exchange=exchange,
-            title=routing_key,
+            title=routing_key.replace("#", "hash"),
         )(coroutine)
 
     return router
