@@ -1,15 +1,13 @@
-from faststream import Context
-from faststream.rabbit import RabbitBroker
 from sqlalchemy import select
 
-
 from bovine.activitystreams.utils import recipients_for_object
 
-from cattle_grid.model import SharedInboxMessage
+from cattle_grid.model import ActivityMessage, SharedInboxMessage
 from cattle_grid.database.activity_pub_actor import Actor, Following
-from cattle_grid.activity_pub.enqueuer import enqueue_from_inbox
-from cattle_grid.dependencies.globals import global_container
-from cattle_grid.dependencies import SqlSession
+from cattle_grid.activity_pub.enqueuer import (
+    determine_activity_type,
+)
+from cattle_grid.dependencies import InternalExchangePublisher, SqlSession
 
 
 def to_result_set(result):
@@ -19,7 +17,7 @@ def to_result_set(result):
 async def handle_shared_inbox_message(
     message: SharedInboxMessage,
     session: SqlSession,
-    broker: RabbitBroker = Context(),
+    publisher: InternalExchangePublisher,
 ):
     """
     This method is used to handle incoming messages from the shared inbox.
@@ -44,8 +42,10 @@ async def handle_shared_inbox_message(
             .where(Following.accepted)
         )
     }
+    activity_type = determine_activity_type(message.data)
+    if activity_type is None:
+        return
 
     for actor in local_actor_ids | following_actor_ids:
-        await enqueue_from_inbox(
-            broker, global_container.internal_exchange, actor, message.data
-        )
+        new_message = ActivityMessage(actor=actor, data=message.data)
+        await publisher(new_message, routing_key=f"incoming.{activity_type}")
