@@ -15,7 +15,9 @@ logger = logging.getLogger(__name__)
 ap_router_object = APIRouter()
 
 
-@ap_router_object.get("/object/{obj_id}", response_class=ActivityResponse)
+@ap_router_object.get(
+    "/object/{obj_id}", response_class=ActivityResponse, tags=["activity_pub"]
+)
 async def return_object(obj_id, headers: ActivityPubHeaders, session: SqlSession):
     """Returns the stored activities"""
 
