@@ -5,8 +5,8 @@ from cattle_grid.testing.cli import *  # noqa
 from .__main__ import main
 
 
-def test_list(db_uri, create_database):
-    runner = CliRunner(env={"CATTLE_GRID_DB_URI": db_uri})
+def test_list(db_url, create_database):
+    runner = CliRunner(env={"CATTLE_GRID_DB_URL": db_url})
     result = runner.invoke(main, ["list"])
 
     assert result.exit_code == 0
