@@ -1,7 +1,7 @@
 from fastapi import FastAPI
 from contextlib import asynccontextmanager
 
-from cattle_grid.dependencies.globals import global_container
+from cattle_grid.app.lifespan import alchemy_database
 from cattle_grid.database.auth import Base
 from cattle_grid.version import __version__
 from .router import auth_router
@@ -14,7 +14,7 @@ def create_app():
 
     @asynccontextmanager
     async def lifespan(app):
-        async with global_container.alchemy_database() as engine:
+        async with alchemy_database() as engine:
             async with engine.begin() as conn:
                 await conn.run_sync(Base.metadata.create_all)
 
