@@ -18,11 +18,11 @@ def async_api_schema_for_component(component: str) -> str:
     if component == "ap":
         from cattle_grid.activity_pub.helper import get_async_api_schema
     elif component == "account":
-        from cattle_grid.account.router.schema import get_async_api_schema
+        from cattle_grid.account.processing.schema import get_async_api_schema
     else:
         from cattle_grid.exchange import get_async_api_schema
 
-    schema = get_async_api_schema().to_json()
+    schema = get_async_api_schema().to_specification().to_json()
 
     return schema
 
