@@ -17,9 +17,9 @@ logger = logging.getLogger(__name__)
 
 @asynccontextmanager
 async def database_engine(
-    db_uri: str = "sqlite+aiosqlite:///:memory:", echo: bool = False
+    db_url: str = "sqlite+aiosqlite:///:memory:", echo: bool = False
 ):
-    engine = create_async_engine(db_uri, echo=echo)
+    engine = create_async_engine(db_url, echo=echo)
 
     yield engine
 
@@ -28,9 +28,9 @@ async def database_engine(
 
 @asynccontextmanager
 async def database_session(
-    db_uri: str = "sqlite+aiosqlite:///:memory:", echo: bool = False
+    db_url: str = "sqlite+aiosqlite:///:memory:", echo: bool = False
 ):
-    async with database_engine(db_uri, echo) as engine:
+    async with database_engine(db_url, echo) as engine:
         async_session = async_sessionmaker(engine)
         async with async_session() as session:
             yield session
@@ -43,7 +43,7 @@ async def upgrade_sql_alchemy(sql_engine):
 
 async def run_with_database(config, coro):
     try:
-        async with database_session(db_uri=config.db_uri) as session:
+        async with database_session(db_url=config.db_url) as session:
             await coro(session)
     except Exception as e:
         logger.exception(e)
