@@ -4,27 +4,18 @@ from sqlalchemy.orm import DeclarativeBase, Mapped, mapped_column
 
 
 class Base(AsyncAttrs, DeclarativeBase):
-    """Base model"""
-
     pass
 
 
 class Credential(Base):
-    """Stored credential"""
+    """Stored credential. This corresponds to storing a private key"""
 
     __tablename__ = "credential"
-    """name of the table"""
 
     id: Mapped[int] = mapped_column(primary_key=True)
-    """primary key"""
-
     actor_id: Mapped[str] = mapped_column(String(256))
-    """The id of the actor the key belongs to"""
     identifier: Mapped[str] = mapped_column(String(256), unique=True)
-    """The identifier of the key"""
-
     secret: Mapped[str] = mapped_column(Text())
-    """The secret underlying the private key"""
 
 
 class InboxLocation(Base):
