@@ -4,16 +4,17 @@ so when building a [fastapi.APIRouter][], one needs to use dependencies
 using the former. These are provided in this package.
 """
 
+import logging
 import aiohttp
 
 from typing import Annotated, Callable, Awaitable, Dict, List
 from dynaconf import Dynaconf
-from faststream.rabbit import RabbitBroker, RabbitExchange
 
 from sqlalchemy.ext.asyncio import AsyncEngine, async_sessionmaker, AsyncSession
 
 from fastapi import Depends
 
+from cattle_grid.app import app_globals as app_globals
 from cattle_grid.model.extension import MethodInformationModel
 from .globals import (
     get_engine,
@@ -21,6 +22,12 @@ from .globals import (
     get_method_information,
     global_container,
 )
+from .fastapi_internals import (
+    ActivityExchangePublisherClass,
+    ActivityExchangeRequesterClass,
+)
+
+logger = logging.getLogger(__name__)
 
 SqlAsyncEngine = Annotated[AsyncEngine, Depends(get_engine)]
 """Returns the SqlAlchemy AsyncEngine"""
@@ -28,15 +35,6 @@ SqlAsyncEngine = Annotated[AsyncEngine, Depends(get_engine)]
 Transformer = Annotated[Callable[[Dict], Awaitable[Dict]], Depends(get_transformer)]
 """The transformer loaded from extensions"""
 
-Broker = Annotated[RabbitBroker, Depends(global_container.get_broker)]
-"""The RabbitMQ broker"""
-InternalExchange = Annotated[
-    RabbitExchange, Depends(global_container.get_internal_exchange)
-]
-
-ActivityExchange = Annotated[RabbitExchange, Depends(global_container.get_exchange)]
-"""The Activity Exchange"""
-
 
 MethodInformation = Annotated[
     List[MethodInformationModel], Depends(get_method_information)
@@ -58,7 +56,7 @@ async def with_committing_sql_session(session: SqlSession):
     await session.commit()
 
 
-CommittingSqlSession = Annotated[AsyncSession, Depends(with_committing_sql_session)]
+CommittingSession = Annotated[AsyncSession, Depends(with_committing_sql_session)]
 """Session annotation to be used with FastAPI. A commit is performed, after processing the request"""
 
 
@@ -67,24 +65,15 @@ Config = Annotated[Dynaconf, Depends(global_container.get_config)]
 
 
 async def get_client_session():
-    yield global_container.session
+    yield app_globals.session
 
 
 ClientSession = Annotated[aiohttp.ClientSession, Depends(get_client_session)]
 """The [aiohttp.ClientSession][] used by the application"""
 
 
-def activity_exchange_publisher(
-    exchange: ActivityExchange,
-    broker: Broker,
-):
-    async def publish(*args, **kwargs):
-        kwargs_updated = {**kwargs}
-        kwargs_updated.update(dict(exchange=exchange))
-        return await broker.publish(*args, **kwargs_updated)
-
-    return publish
-
-
-ActivityExchangePublisher = Annotated[Callable, Depends(activity_exchange_publisher)]
+ActivityExchangePublisher = Annotated[Callable, Depends(ActivityExchangePublisherClass)]
 """Publisher to the activity exchange"""
+
+ActivityExchangeRequester = Annotated[Callable, Depends(ActivityExchangeRequesterClass)]
+"""Requester to the activity exchange"""
