@@ -1,12 +1,11 @@
 import logging
 
-from faststream import FastStream
+from faststream.specification import AsyncAPI
 from faststream.rabbit import RabbitRouter, RabbitExchange, RabbitQueue
-from faststream.asyncapi.schema import Schema
 from typing import Any, List, Tuple
 
+from cattle_grid.app import app_globals
 from cattle_grid.version import __version__
-from cattle_grid.dependencies.globals import global_container
 
 from .exception import exception_middleware
 from .info import add_method_information
@@ -20,23 +19,23 @@ logger = logging.getLogger(__name__)
 
 
 def create_router(
-    main_exchange: RabbitExchange | None = None, include_shovels=True
+    activity_exchange: RabbitExchange | None = None, include_shovels=True
 ) -> RabbitRouter:
     """Creates a router to be used to manage users"""
 
-    if main_exchange is None:
-        main_exchange = global_container.exchange
+    if activity_exchange is None:
+        activity_exchange = app_globals.activity_exchange
 
     router = RabbitRouter(middlewares=[exception_middleware])
 
     if include_shovels:
         router.subscriber(
             RabbitQueue("incoming_shovel", routing_key="incoming.#", durable=True),
-            global_container.internal_exchange,
+            app_globals.internal_exchange,
         )(incoming_shovel)
         router.subscriber(
             RabbitQueue("outgoing_shovel", routing_key="outgoing.#", durable=True),
-            global_container.internal_exchange,
+            app_globals.internal_exchange,
         )(outgoing_shovel)
 
     routing_config: List[Tuple[str, Any]] = [
@@ -53,14 +52,14 @@ def create_router(
     for routing_key, coroutine in routing_config:
         router.subscriber(
             RabbitQueue(prefix + routing_key, routing_key=routing_key, durable=True),
-            exchange=main_exchange,
+            exchange=activity_exchange,
             title=routing_key,
         )(coroutine)
 
     return router
 
 
-def get_mock_faststream_app() -> FastStream:
+def get_async_api_schema() -> AsyncAPI:
     from faststream.rabbit import RabbitBroker
 
     broker = RabbitBroker()
@@ -92,17 +91,9 @@ def get_mock_faststream_app() -> FastStream:
     #         read activity with URI id on this device. These might also be send through this exchange.
     #     """
 
-    return FastStream(
+    return AsyncAPI(
         broker,
         title="cattle_grid exchange",
         version=__version__,
         description="Exchange in cattle_grid that applications using cattle_grid as middle ware are supposed to subscribe to",
     )
-
-
-def get_async_api_schema() -> Schema:
-    from faststream.asyncapi import get_app_schema
-
-    app = get_mock_faststream_app()
-
-    return get_app_schema(app)
