@@ -32,7 +32,7 @@ async def exception_handler(
         return
 
     logger.info("Exception for %s", actor_id)
-    logger.debug(exception)
+    logger.debug(exception, exc_info=True)
     account = await account_for_actor(session, actor_id)
     if not account:
         return
