@@ -1,4 +1,5 @@
 import logging
+from typing import Any
 
 from sqlalchemy import select, func
 from sqlalchemy.ext.asyncio import AsyncSession
@@ -6,7 +7,7 @@ from sqlalchemy.ext.asyncio import AsyncSession
 from bovine.activitystreams.utils import id_for_object
 
 from cattle_grid.dependencies.internals import Transformer
-from cattle_grid.model import ActivityMessage as RawActivityMessage
+from cattle_grid.model import ActivityMessage
 from cattle_grid.database.activity_pub_actor import Actor, Blocking
 
 from cattle_grid.dependencies import (
@@ -18,6 +19,7 @@ from cattle_grid.dependencies import (
 
 from cattle_grid.database.account import ActorForAccount
 from cattle_grid.model.account import EventInformation, EventType
+from cattle_grid.model.exchange import TransformedActivityMessage
 
 logger = logging.getLogger(__name__)
 
@@ -47,10 +49,50 @@ async def should_shovel_activity(session: AsyncSession, activity: dict) -> bool:
     return True
 
 
-async def incoming_shovel(
-    msg: RawActivityMessage,
-    transformer: Transformer,
+async def shovel(
+    actor: str,
+    activity: dict[str, Any],
     session: SqlSession,
+    transformer: Transformer,
+    publisher: ActivityExchangePublisher,
+    account_publisher: AccountExchangePublisher,
+    direction: EventType,
+):
+    actor_for_account = await session.scalar(
+        select(ActorForAccount).where(ActorForAccount.actor == actor)
+    )
+    if actor_for_account is None:
+        logger.warning("Got actor without account %s", actor)
+        return
+
+    account_name = actor_for_account.account.name
+    to_shovel = await transformer({"raw": activity}, actor_id=actor)
+    activity_type = activity.get("type")
+
+    event_info = EventInformation(
+        actor=actor,
+        event_type=direction,
+        data=to_shovel,
+    )
+
+    await account_publisher(
+        event_info,
+        routing_key=f"receive.{account_name}.{str(direction)}",
+    )
+    await account_publisher(
+        event_info,
+        routing_key=f"receive.{account_name}.{str(direction)}.{activity_type}",
+    )
+    await publisher(
+        TransformedActivityMessage(actor=actor, data=to_shovel),
+        routing_key=f"{str(direction)}.{activity_type}",
+    )
+
+
+async def incoming_shovel(
+    msg: ActivityMessage,
+    session: SqlSession,
+    transformer: Transformer,
     publisher: ActivityExchangePublisher,
     account_publisher: AccountExchangePublisher,
 ) -> None:
@@ -59,17 +101,9 @@ async def incoming_shovel(
 
     The message is passed through the transformer.
     """
-    actor_for_account = await session.scalar(
-        select(ActorForAccount).where(ActorForAccount.actor == msg.actor)
-    )
+    logger.info("incoming shovel")
 
-    if actor_for_account is None:
-        logger.warning("Got actor without account %s", msg.actor)
-        return
-
-    activity = msg.data
-
-    if not await should_shovel_activity(session, activity):
+    if not await should_shovel_activity(session, msg.data):
         return
 
     # FIXME: Use join to combine the next two queries ...
@@ -81,68 +115,36 @@ async def incoming_shovel(
     blocking = await session.scalar(
         select(Blocking)
         .where(Blocking.actor == db_actor)
-        .where(Blocking.blocking == activity.get("actor"))
+        .where(Blocking.blocking == msg.data.get("actor"))
         .where(Blocking.active)
     )
     if blocking:
         return
 
-    account_name = actor_for_account.account.name
-    to_shovel = await transformer({"raw": msg.data}, actor_id=msg.actor)
-    activity_type = msg.data.get("type")
-
-    await account_publisher(
-        EventInformation(
-            actor=msg.actor,
-            event_type=EventType.incoming,
-            data=to_shovel,
-        ),
-        routing_key=f"receive.{account_name}.incoming",
-    )
-
-    await publisher(
-        {
-            "actor": msg.actor,
-            "data": to_shovel,
-        },
-        routing_key=f"incoming.{activity_type}",
+    return await shovel(
+        msg.actor,
+        msg.data,
+        direction=EventType.incoming,
+        transformer=transformer,
+        publisher=publisher,
+        account_publisher=account_publisher,
+        session=session,
     )
 
 
 async def outgoing_shovel(
-    msg: RawActivityMessage,
+    msg: ActivityMessage,
     transformer: Transformer,
-    session: SqlSession,
     publisher: ActivityExchangePublisher,
     account_publisher: AccountExchangePublisher,
+    session: SqlSession,
 ) -> None:
-    actor_for_account = await session.scalar(
-        select(ActorForAccount).where(ActorForAccount.actor == msg.actor)
-    )
-
-    logger.debug("OUTGOING SHOVEL")
-
-    if actor_for_account is None:
-        logger.warning("Actor %s for account not found", msg.actor)
-        return
-
-    account_name = actor_for_account.account.name
-    to_shovel = await transformer({"raw": msg.data}, actor_id=msg.actor)
-    activity_type = msg.data.get("type")
-
-    await account_publisher(
-        EventInformation(
-            actor=msg.actor,
-            event_type=EventType.outgoing,
-            data=to_shovel,
-        ),
-        routing_key=f"receive.{account_name}.outgoing",
-    )
-
-    await publisher(
-        {
-            "actor": msg.actor,
-            "data": to_shovel,
-        },
-        routing_key=f"outgoing.{activity_type}",
+    return await shovel(
+        msg.actor,
+        msg.data,
+        direction=EventType.outgoing,
+        transformer=transformer,
+        publisher=publisher,
+        account_publisher=account_publisher,
+        session=session,
     )
