@@ -1,23 +1,57 @@
 import pytest
 
 from unittest.mock import AsyncMock
+from faststream.rabbit import RabbitBroker, TestRabbitBroker, RabbitQueue
 
+from cattle_grid.app import app_globals
 from cattle_grid.model import ActivityMessage
 from cattle_grid.activity_pub.actor import create_actor
 from cattle_grid.database.activity_pub_actor import Blocking
 from cattle_grid.testing.fixtures import *  # noqa
+from cattle_grid.dependencies.globals import global_container
 
-from .shovel import incoming_shovel, should_shovel_activity
+from .shovel import should_shovel_activity
+from . import create_router
+
+
+@pytest.fixture
+def mock_incoming():
+    return AsyncMock(return_value=None)
+
+
+@pytest.fixture
+def mock_outgoing():
+    return AsyncMock(return_value=None)
 
 
 async def fake_transformer(a, **kwargs):
     return a
 
 
-async def test_incoming_message(sql_session, actor_with_account):
-    publisher = AsyncMock()
-    account_publisher = AsyncMock()
+@pytest.fixture
+async def test_broker(mock_incoming, mock_outgoing):
+    broker = RabbitBroker()
+    broker.include_router(create_router())
 
+    broker.subscriber(
+        RabbitQueue("incoming", routing_key="incoming.*"),
+        app_globals.activity_exchange,
+    )(mock_incoming)
+    broker.subscriber(
+        RabbitQueue("outgoing", routing_key="outgoing.*"),
+        app_globals.activity_exchange,
+    )(mock_outgoing)
+    broker.subscriber(
+        RabbitQueue("receive", routing_key="receive.#"),
+        app_globals.account_exchange,
+    )(AsyncMock(return_value=None))
+    global_container.transformer = fake_transformer
+
+    async with TestRabbitBroker(broker) as tbr:
+        yield tbr
+
+
+async def test_incoming_message(test_broker, mock_incoming, actor_with_account):
     activity_pub = {
         "@context": "https://www.w3.org/ns/activitystreams",
         "id": "http://remote.test/activity_id",
@@ -32,27 +66,21 @@ async def test_incoming_message(sql_session, actor_with_account):
         data=activity_pub,
     )
 
-    await incoming_shovel(
+    await test_broker.publish(
         activity,
-        fake_transformer,
-        session=sql_session,
-        publisher=publisher,
-        account_publisher=account_publisher,
+        exchange=app_globals.internal_exchange,
+        routing_key="incoming.Activity",
     )
 
-    publisher.assert_awaited_once()
-    account_publisher.assert_awaited_once()
+    mock_incoming.assert_awaited_once()
 
-    args = publisher.call_args[0]
-    result = args[0]
+    args = mock_incoming.call_args[1]
+    result = args["data"]
 
-    assert result["data"]["raw"]["@context"] == activity_pub["@context"]
+    assert result["raw"]["@context"] == activity_pub["@context"]
 
 
-async def test_incoming_block(sql_session, actor_with_account):
-    publisher = AsyncMock()
-    account_publisher = AsyncMock()
-
+async def test_incoming_block(test_broker, mock_incoming, actor_with_account):
     activity_pub = {
         "@context": "https://www.w3.org/ns/activitystreams",
         "id": "http://remote.test/activity_id",
@@ -64,21 +92,18 @@ async def test_incoming_block(sql_session, actor_with_account):
 
     activity = ActivityMessage(actor=actor_with_account.actor_id, data=activity_pub)
 
-    await incoming_shovel(
+    await test_broker.publish(
         activity,
-        fake_transformer,
-        session=sql_session,
-        publisher=publisher,
-        account_publisher=account_publisher,
+        exchange=app_globals.internal_exchange,
+        routing_key="incoming.Activity",
     )
 
-    publisher.assert_not_awaited()
+    mock_incoming.assert_not_awaited()
 
 
-async def test_incoming_from_blocked_user(sql_session, actor_with_account):
-    publisher = AsyncMock()
-    account_publisher = AsyncMock()
-
+async def test_incoming_from_blocked_user(
+    test_broker, mock_incoming, sql_session, actor_with_account
+):
     remote_actor = "http://remote.test/actor"
 
     sql_session.add(
@@ -105,21 +130,17 @@ async def test_incoming_from_blocked_user(sql_session, actor_with_account):
         data=activity_pub,
     )
 
-    await incoming_shovel(
+    await test_broker.publish(
         activity,
-        fake_transformer,
-        session=sql_session,
-        publisher=publisher,
-        account_publisher=account_publisher,
+        exchange=app_globals.internal_exchange,
+        routing_key="incoming.Activity",
     )
-    publisher.assert_not_awaited()
+    mock_incoming.assert_not_awaited()
 
 
 async def test_incoming_from_blocked_user_inactive_block(
-    sql_session, actor_with_account
+    test_broker, mock_incoming, sql_session, actor_with_account
 ):
-    publisher = AsyncMock()
-    account_publisher = AsyncMock()
     remote_actor = "http://remote.test/actor"
 
     sql_session.add(
@@ -146,18 +167,17 @@ async def test_incoming_from_blocked_user_inactive_block(
         data=activity_pub,
     )
 
-    await incoming_shovel(
+    await test_broker.publish(
         activity,
-        fake_transformer,
-        session=sql_session,
-        publisher=publisher,
-        account_publisher=account_publisher,
+        exchange=app_globals.internal_exchange,
+        routing_key="incoming.Activity",
     )
-    publisher.assert_awaited_once()
-    account_publisher.assert_awaited_once()
+    mock_incoming.assert_awaited_once()
 
 
-async def test_incoming_message_non_gateway_actor(sql_session):
+async def test_incoming_message_non_gateway_actor(
+    test_broker, mock_incoming, sql_session
+):
     actor = await create_actor(
         sql_session, "http://localhost/", preferred_username="bob"
     )
@@ -170,21 +190,16 @@ async def test_incoming_message_non_gateway_actor(sql_session):
         "object": "http://actor.example/object",
     }
 
-    publisher = AsyncMock()
-    account_publisher = AsyncMock()
     activity = ActivityMessage(
         actor=actor.actor_id,
         data=activity_pub,
     )
-
-    await incoming_shovel(
+    await test_broker.publish(
         activity,
-        fake_transformer,
-        session=sql_session,
-        publisher=publisher,
-        account_publisher=account_publisher,
+        exchange=app_globals.internal_exchange,
+        routing_key="incoming.Activity",
     )
-    publisher.assert_not_awaited()
+    mock_incoming.assert_not_awaited()
 
 
 @pytest.mark.parametrize(
