@@ -1,11 +1,13 @@
 import datetime
 
-from sqlalchemy import ForeignKey, String, func, JSON
+from sqlalchemy import Enum, ForeignKey, String, func, JSON
 from sqlalchemy.ext.asyncio import AsyncAttrs
 from sqlalchemy.orm import DeclarativeBase, Mapped, mapped_column, relationship
 
 from sqlalchemy_utils.types import UUIDType
 
+from cattle_grid.extensions.examples.html_display.types import InteractionType
+
 
 class Base(AsyncAttrs, DeclarativeBase):
     """Base model"""
@@ -32,6 +34,27 @@ class PublishedObject(Base):
     actor: Mapped[str] = mapped_column()
     create_date: Mapped[datetime.datetime] = mapped_column(server_default=func.now())
 
+    interactions: Mapped[list["PublishedObjectInteraction"]] = relationship(
+        viewonly=True
+    )
+
+
+class PublishedObjectInteraction(Base):
+    """HTML display object in the database"""
+
+    __tablename__ = "html_display_stored_object_interaction"
+
+    id: Mapped[bytes] = mapped_column(UUIDType(binary=True), primary_key=True)
+
+    published_object_id: Mapped[str] = mapped_column(
+        ForeignKey("html_display_stored_object.id")
+    )
+    published_object: Mapped[PublishedObject] = relationship()
+
+    object_id: Mapped[str] = mapped_column()
+
+    interaction: Mapped[InteractionType] = mapped_column(Enum(InteractionType))
+
 
 class ExportPermission(Base):
     """Records a one time token required to download the export"""
