@@ -28,6 +28,8 @@ async def publishing_actor_for_actor_id(session: AsyncSession, actor_id: str):
 
     actor = PublishingActor(actor=actor_id, name=new_name())
     session.add(actor)
+    await session.commit()
+    await session.refresh(actor)
     return actor
 
 
