@@ -1,5 +1,5 @@
 from sqlalchemy import select
-from cattle_grid.dependencies.globals import global_container
+from cattle_grid.app import access_methods
 from cattle_grid.extensions.examples.html_display.database import PublishingActor
 from cattle_grid.extensions.examples.html_display.types import NameActorMessage
 from cattle_grid.manage.actor import ActorManager
@@ -22,7 +22,7 @@ async def test_publish_html(
     await test_broker.publish(
         ActivityMessage(actor=actor_for_test.actor_id, data=obj),
         routing_key="html_display_publish_object",
-        exchange=global_container.exchange,
+        exchange=access_methods.get_activity_exchange(),
     )
 
     mock_publish_activity.assert_awaited_once()
@@ -46,7 +46,7 @@ async def test_publish_html_private(
     await test_broker.publish(
         ActivityMessage(actor=actor_for_test.actor_id, data=obj),
         routing_key="html_display_publish_object",
-        exchange=global_container.exchange,
+        exchange=access_methods.get_activity_exchange(),
     )
 
     mock_publish_activity.assert_not_awaited()
@@ -57,7 +57,7 @@ async def test_rename_actor(test_broker, actor_with_account, sql_session):
     await test_broker.publish(
         NameActorMessage(actor=actor_with_account.actor_id, name="sue"),
         routing_key="html_display_name",
-        exchange=global_container.exchange,
+        exchange=access_methods.get_activity_exchange(),
     )
 
     actor = await sql_session.scalar(
@@ -82,7 +82,7 @@ async def test_rename_actor_and_add_to_group(
     await test_broker.publish(
         NameActorMessage(actor=actor_with_account.actor_id, name="sue"),
         routing_key="html_display_name",
-        exchange=global_container.exchange,
+        exchange=access_methods.get_activity_exchange(),
     )
 
     actor = await sql_session.scalar(
