@@ -1,7 +1,5 @@
-from uuid import UUID
-
 from .database import PublishingActor
-from .storage import object_for_name_and_uuid, publishing_actor_for_actor_id
+from .storage import object_for_object_id, publishing_actor_for_actor_id
 
 from .testing import *  # noqa
 
@@ -27,9 +25,17 @@ async def test_publishing_actor_for_actor_id_returns_stored_actor(sql_session):
     assert one.name == two.name
 
 
-async def test_object_for_name_and_uuid_not_found(sql_session):
-    result = await object_for_name_and_uuid(
-        sql_session, "name", UUID("2fd16a00-309b-4f3a-9d91-aa9516e59c1f")
-    )
+async def test_object_for_object_id_unknown(sql_session):
+    object_id = "http://object.test/some/id"
+
+    result = await object_for_object_id(sql_session, object_id)
 
     assert result is None
+
+
+async def test_object_for_object_id(sql_session, published_object):
+    object_id = published_object.get("id")
+
+    result = await object_for_object_id(sql_session, object_id)
+
+    assert result
