@@ -1,3 +1,4 @@
+import logging
 from unittest.mock import AsyncMock
 import pytest
 
@@ -5,18 +6,21 @@ from fastapi import FastAPI
 from fastapi.testclient import TestClient
 
 
+from cattle_grid.app import app_globals
 from cattle_grid.extensions.examples.html_display.storage import (
     publishing_actor_for_actor_id,
 )
 from cattle_grid.extensions.testing import with_test_broker_for_extension
 from cattle_grid.model import ActivityMessage
-from cattle_grid.dependencies.globals import global_container
 from cattle_grid.testing.fixtures import *  # noqa
 from cattle_grid.extensions.util import lifespan_for_sql_alchemy_base_class
 from .database import Base
 from . import extension
 
 
+logger = logging.getLogger(__name__)
+
+
 @pytest.fixture(autouse=True)
 async def create_tables(sql_engine_for_tests):
     lifespan = lifespan_for_sql_alchemy_base_class(Base)
@@ -26,12 +30,12 @@ async def create_tables(sql_engine_for_tests):
 
 @pytest.fixture
 def mock_publish_activity():
-    return AsyncMock()
+    return AsyncMock(return_value=None)
 
 
 @pytest.fixture
 def mock_publish_object():
-    return AsyncMock()
+    return AsyncMock(return_value=None)
 
 
 @pytest.fixture
@@ -43,6 +47,7 @@ async def test_broker(mock_publish_activity, mock_publish_object):
         {
             "publish_activity": mock_publish_activity,
             "publish_object": mock_publish_object,
+            "update_actor": AsyncMock(),
         },
     ) as tbr:
         yield tbr
@@ -58,11 +63,13 @@ async def published_object(actor_for_test, test_broker, mock_publish_activity):
     }
 
     await test_broker.publish(
-        ActivityMessage(actor=actor_for_test.actor_id, data=obj),
+        ActivityMessage(actor=actor_for_test.actor_id, data=obj).model_dump(),
         routing_key="html_display_publish_object",
-        exchange=global_container.exchange,
+        exchange=app_globals.activity_exchange,
     )
 
+    logger.info("created object")
+
     mock_publish_activity.assert_awaited_once()
 
     args = mock_publish_activity.await_args
