@@ -25,7 +25,7 @@ class SimpleStorageConfiguration(BaseModel):
 
     prefix: str = Field(
         "/simple_storage/",
-        description="Path to use before the generated uuid. The protocol and domain will be extracted from the actor id. See [cattle_grid.extensions.examples.simple_storage.config.determine_url_start][].",
+        description="Path to use before the generated uuid. The protocol and domain will be extracted from the actor id. See [determine_url_start][cattle_grid.extensions.examples.simple_storage.config.determine_url_start].",
     )
 
     def url_start(self, actor_id):
