@@ -1,15 +1,13 @@
 from fastapi import FastAPI
 
-from faststream import FastStream
 from faststream.rabbit import RabbitBroker
-from faststream.asyncapi import get_app_schema
-from faststream.asyncapi.schema import Schema
+from faststream.specification import AsyncAPI
 
 from . import Extension
 from .load.lifespan import lifespan_for_extension
 
 
-def async_schema_for_extension(extension: Extension) -> Schema:
+def async_schema_for_extension(extension: Extension) -> AsyncAPI:
     """Converts the activity router of the extension to
     a [Schema][faststream.asyncapi.schema.Schema].
 
@@ -20,9 +18,7 @@ def async_schema_for_extension(extension: Extension) -> Schema:
     if extension.activity_router:
         broker.include_router(extension.activity_router)
 
-    app = FastStream(broker, title=extension.name)
-
-    return get_app_schema(app)
+    return AsyncAPI(broker, title=extension.name)
 
 
 def fastapi_for_extension(
