@@ -1,8 +1,5 @@
-from unittest.mock import AsyncMock
-import aiohttp
-
-from cattle_grid.dependencies.globals import global_container
 from cattle_grid.model.lookup import Lookup
+from cattle_grid.testing import mocked_session
 
 from . import build_lookup, load_extension, collect_method_information
 
@@ -11,16 +8,10 @@ async def test_build_lookup():
     extensions = [
         load_extension({"module": "cattle_grid.extensions.examples.webfinger_lookup"})
     ]
-
-    lookup = build_lookup(extensions)
-
-    data = Lookup(uri="http://remote.example", actor="http://actor.example")
-
-    global_container.session = AsyncMock(aiohttp.ClientSession)
-
-    await lookup(data)
-
-    global_container.session = None
+    with mocked_session():
+        lookup = build_lookup(extensions)
+        data = Lookup(uri="http://remote.example", actor="http://actor.example")
+        await lookup(data)
 
 
 async def test_collect_method_information():
@@ -30,9 +21,10 @@ async def test_collect_method_information():
 
     method_information = collect_method_information(extensions)
 
-    assert len(method_information) == 2
+    assert len(method_information) == 3
 
     assert {x.routing_key for x in method_information} == {
         "publish_activity",
         "publish_object",
+        "admin_simple_storage",
     }
