@@ -2,9 +2,8 @@ from contextlib import asynccontextmanager
 from typing import Callable
 from faststream.rabbit import RabbitBroker, TestRabbitBroker, RabbitQueue
 
-from cattle_grid.dependencies.globals import global_container
-
-
+from cattle_grid.app import app_globals
+from cattle_grid.testing.fixtures import *  # noqa
 from .load import add_routers_to_broker
 
 
@@ -27,9 +26,9 @@ async def with_test_broker_for_extension(
     for routing_key, subscriber in subscribers.items():
         broker.subscriber(
             RabbitQueue(routing_key, routing_key=routing_key),
-            exchange=global_container.exchange,
+            exchange=app_globals.activity_exchange,
         )(subscriber)
 
     add_routers_to_broker(broker, extensions)
-    async with TestRabbitBroker(broker) as tbr:
+    async with TestRabbitBroker(broker, with_real=False) as tbr:
         yield tbr
