@@ -1,4 +1,8 @@
+from collections.abc import Callable
 from contextlib import asynccontextmanager
+from typing import Any
+
+from faststream.rabbit import RabbitQueue
 
 from cattle_grid.dependencies import SqlAsyncEngine
 
@@ -28,7 +32,9 @@ def skip_method_information(routing_key):
     return False
 
 
-def lifespan_for_sql_alchemy_base_class(base_class):
+def lifespan_for_sql_alchemy_base_class(
+    base_class,
+) -> Callable[[SqlAsyncEngine], Any]:
     """Creates a lifespan that creates the sql alchemy models for the base_class.
 
     Usage
@@ -50,3 +56,11 @@ def lifespan_for_sql_alchemy_base_class(base_class):
         yield
 
     return lifespan
+
+
+def rabbit_queue_for_name_and_routing_key(name, routing_key):
+    return RabbitQueue(
+        name.replace(" ", "_") + "_" + routing_key,
+        routing_key=routing_key,
+        durable=True,
+    )
