@@ -4,18 +4,11 @@ from typing import List, Dict, Any
 from enum import StrEnum, auto
 from pydantic import BaseModel, Field, ConfigDict
 
+from .common import WithTransformedData, WithActor
+
 from .extension import MethodInformationModel
 
 
-class WithActor(BaseModel):
-    """Used as base for messages requiring an actor"""
-
-    actor: str = Field(
-        examples=["http://host.example/actor/1"],
-        description="""The actor performing the action""",
-    )
-
-
 class FetchMessage(WithActor):
     """Message to fetch an object from the Fediverse"""
 
@@ -168,7 +161,7 @@ class EventType(StrEnum):
     error = auto()
 
 
-class EventInformation(WithActor):
+class EventInformation(WithActor, WithTransformedData):
     """Send on outgoing or incoming events"""
 
     event_type: EventType = Field(
@@ -180,19 +173,6 @@ incoming means that the contained data was not generated on the actors behalf.
 outgoing means that the data is being send out by the actor.""",
     )
 
-    data: Dict[str, Any] = Field(
-        examples=[
-            {
-                "raw": {
-                    "@context": "https://www.w3.org/ns/activitystreams",
-                    "type": "Create",
-                    "actor": "http://host.example/actor/1",
-                }
-            }
-        ],
-        description="""The data that was exchanged. We note that this data was processed by the transformers.""",
-    )
-
 
 class ErrorMessage(BaseModel):
     """Message to send an exception"""
