@@ -1,10 +1,14 @@
 from pydantic import ConfigDict, Field, field_serializer
-from typing import Dict, Any, List
+from typing import Annotated, Dict, Any, List
 
-from .common import WithActor
+from .common import WithActor, WithTransformedData
 from .exchange_update_actor import UpdateAction
 
 
+class TransformedActivityMessage(WithActor, WithTransformedData):
+    """Transformed activity message"""
+
+
 class UpdateActorMessage(WithActor):
     """
     Allows one to update the actor object
@@ -29,7 +33,14 @@ class UpdateActorMessage(WithActor):
     """,
     )
 
-    actions: List[UpdateAction] = Field(
+    actions: List[
+        Annotated[
+            UpdateAction,
+            Field(
+                discriminator="action",
+            ),
+        ]
+    ] = Field(
         default_factory=list,
         description="""Actions to be taken when updating the profile""",
     )
