@@ -5,6 +5,9 @@ import logging
 
 from contextlib import asynccontextmanager
 
+from cattle_grid.app import app_globals
+from cattle_grid.app.lifespan import common_lifespan
+
 from .app import add_routers_to_broker, init_extensions
 
 from .dependencies.globals import global_container
@@ -14,13 +17,14 @@ from .extensions.load import (
 )
 from .exchange.exception import exception_middleware
 
-logging.basicConfig(level=logging.DEBUG)
+logging.basicConfig(level=logging.INFO)
 
 global_container.load_config()
+
 extensions = init_extensions(global_container.config)
 
 broker = RabbitBroker(
-    global_container.config.amqp_uri,  # type:ignore
+    app_globals.application_config.amqp_url,  # type:ignore
     middlewares=[exception_middleware],
 )
 add_routers_to_broker(broker, extensions, global_container.config)
@@ -28,7 +32,7 @@ add_routers_to_broker(broker, extensions, global_container.config)
 
 @asynccontextmanager
 async def lifespan():
-    async with global_container.common_lifecycle(global_container.config):
+    async with common_lifespan():
         async with lifespan_from_extensions(extensions):
             yield
 
@@ -38,5 +42,7 @@ app = FastStream(broker, lifespan=lifespan)
 
 @app.after_startup
 async def declare_exchanges() -> None:
-    await broker.declare_exchange(global_container.internal_exchange)
-    await broker.declare_exchange(global_container.exchange)
+    if app_globals.internal_exchange:
+        await broker.declare_exchange(app_globals.internal_exchange)
+    if app_globals.activity_exchange:
+        await broker.declare_exchange(app_globals.activity_exchange)
