@@ -5,7 +5,7 @@ from cattle_grid.database.activity_pub_actor import Actor
 
 
 async def statistics(config):
-    async with database_session(db_uri=config.db_uri) as session:
+    async with database_session(db_url=config.db_url) as session:
         remote_identity_count = await session.scalar(func.count(RemoteIdentity.id))
         actor_count = await session.scalar(func.count(Actor.id))
 
