@@ -5,14 +5,14 @@ from cattle_grid.database import database_engine
 
 
 @pytest.fixture
-def db_uri(tmp_path):
+def db_url(tmp_path):
     return "sqlite+aiosqlite:///" + str(tmp_path / "test.db")
 
 
 @pytest.fixture
-def create_database(db_uri):
+def create_database(db_url):
     async def run_method():
-        async with database_engine(db_uri=db_uri) as engine:
+        async with database_engine(db_url=db_url) as engine:
             from cattle_grid.database.activity_pub import Base as APBase
 
             async with engine.begin() as conn:
