@@ -7,3 +7,5 @@ from .account import *  # noqa
 from .message_content import *  # noqa
 from .drive import *  # noqa
 from .http import *  # noqa
+from .fetch import *  # noqa
+from .interactions import *  # noqa
