@@ -1,6 +1,6 @@
 from typing import Annotated
 from fastapi import Depends, Header
-from fastapi.responses import JSONResponse
+from fastapi.responses import JSONResponse, StreamingResponse
 from pydantic import BaseModel, Field
 
 from .http_util import ContentType, should_server_from_accept
@@ -9,11 +9,26 @@ __all__ = [
     "ActivityResponse",
     "APHeaders",
     "ActivityPubHeaders",
+    "JrdResponse",
     "ShouldServe",
     "ContentType",
 ]
 
 
+class EventStreamResponse(StreamingResponse):
+    """Response that ensures the content-type is `text/event-stream`"""
+
+    media_type = "text/event-stream"
+
+
+class JrdResponse(JSONResponse):
+    """Response that ensures the content-type is
+    "application/jrd+json"
+    """
+
+    media_type = "application/jrd+json"
+
+
 class ActivityResponse(JSONResponse):
     """Response that ensures the content-type is
     "application/activity+json"
