@@ -1,4 +1,4 @@
-from cattle_grid.testing.features import (
+from cattle_grid.testing.features.environment import (
     before_all,  # noqa
     before_scenario,  # noqa
     after_scenario,  # noqa
