@@ -5,7 +5,8 @@ set -eux
 DOCKER_DIR=resources/docker_dev
 REQUIREMENTS_FILE=${DOCKER_DIR}/requirements.txt
 
-uv export --no-editable --no-emit-project --no-hashes > $REQUIREMENTS_FILE
+uv export --no-editable --no-emit-project --no-hashes\
+    --extra postgres --extra uvicorn --extra cache  > $REQUIREMENTS_FILE
 
 sed -i '/argon2-cffi-bindings==21.2.0/d' $REQUIREMENTS_FILE
 sed -i '/.*whl/d' $REQUIREMENTS_FILE
@@ -14,6 +15,8 @@ for file in $(ls ${DOCKER_DIR}/*.whl); do
     rm $file
 done
 
-cp *.whl $DOCKER_DIR
+for file in $(ls *.whl); do
+    cp $file $DOCKER_DIR
+done
 
-docker compose build
\ No newline at end of file
+docker compose build
